<?php
// src/Bootstrap.php
use Doctrine\ORM\Tools\Setup;
use Doctrine\ORM\EntityManager;
use Config\MyLoggerConfigurator;

class Bootstrap{
    
    private static $devLogLevel='debug';
    
    /**
     * 
     * @var bool
     */
    private static $isDevMode = false;
    
    /**
     * 
     * @var EntityManager
     */
    private static $entityManager = null;
    
    private static function initDevMode() : void {
        self::$isDevMode = in_array( APPLICATION_ENV , array('development'));
    }
    
    private static function initLogging(){
        // User defined configuration (optional)
        $configuration = array(
            'file' => 1,
            'mailEvent' => 2
        );
        $fileParams=array('file'=>__DIR__.'/../log/' .(self::$isDevMode ? 'dev' : 'prod') .'/cours.log' , 'level' => self::$isDevMode ? self::$devLogLevel : 'warn');
        $mailsParamsConfig = \MailConfig::getMailParams();
        $mailParams=array('to' => $mailsParamsConfig['toLog'], 'from' => $mailsParamsConfig['from'] , 'level' => 'fatal');
        // Passing the configurator as an instance
        Logger::configure($configuration, new MyLoggerConfigurator($fileParams, $mailParams));
    }
    
    private static function initDatabase() : void{
        // Create a simple "default" Doctrine ORM configuration for Annotations
        $config = Setup::createAnnotationMetadataConfiguration(array(__DIR__), self::$isDevMode);
        // or if you prefer XML
        //$config = Setup::createXMLMetadataConfiguration(array(__DIR__."/config"), $isDevMode);
        // database configuration parameters
        $conn = \Doctrine\DBAL\DriverManager::getConnection(Database::getConnectionParams(), $config);
        
        // obtaining the entity manager
        self::$entityManager = EntityManager::create($conn, $config);
    }
    
    
    public static function init() : void{
        self::initDevMode();
        self::initLogging();
        self::initDatabase();
    }
    
    /**
     * Donne access à l'EntityManager d'accès à la base
     * @return EntityManager
     */
    public static function getEntityManager() : EntityManager{
        return self::$entityManager;
    }
}
