<?php
namespace Config;

use \LoggerConfigurator;
use \LoggerHierarchy;
use \LoggerAppenderDailyFile;
use \LoggerAppenderMailEvent;
use \LoggerLayoutPattern;

/**
 * La classe de configuration du logger log4php
 * @author Christophe PEQUIGNAT
 *
 */
class MyLoggerConfigurator implements LoggerConfigurator
{
    
    private $fileParams;
    private $mailParams;
    
    /**
     * 
     * @param array $fileParams
     * @param array $mailParams
     */
    public function __construct(array $fileParams, array $mailParams){
        $this->fileParams = $fileParams;
        $this->mailParams = $mailParams;
    }
    
    
    /**
     * {@inheritDoc}
     * @see LoggerConfigurator::configure()
     */
    public function configure(LoggerHierarchy $hierarchy, $input = null)
    {
        // Use a different layout for the next appender
        $layout = new LoggerLayoutPattern();
        $layout->setConversionPattern("%d{ISO8601} %level [%logger] %msg%newline");
        $layout->activateOptions();
        
        // Create an appender which logs to file
        $appFile = new LoggerAppenderDailyFile('file');
        $appFile->setFile( $this->fileParams['file'] );
        $appFile->setAppend(true);
        $appFile->setThreshold($this->fileParams['level']);
        $appFile->setLayout($layout);
        $appFile->activateOptions();
        
        // Create an appender which logs to file
        $appMailEvent = new LoggerAppenderMailEvent('mailEvent');
        $appMailEvent->setLayout($layout);
        $appMailEvent->setThreshold($this->mailParams['level']);
        $appMailEvent->setFrom($this->mailParams['from']);
        $appMailEvent->setTo($this->mailParams['to']);
        $appMailEvent->activateOptions();
        
        // Add both appenders to the root logger
        $root = $hierarchy->getRootLogger();
        $root->addAppender($appFile);
        $root->addAppender($appMailEvent);
    }

}

