<?php
namespace Entity;

use Doctrine\ORM\Mapping\Entity as Entity;

/**
 * @Entity(repositoryClass="Repository\PersonRepository")
 * @Table(name="PERSON")
 * 
 * @author Christophe PEQUIGNAT
 */
class Person
{

    /**
     * @Id
     * @Column(type="integer", name="PERSON_ID")
     * @GeneratedValue
     * 
     * @var int
     */
    private $id;

    /**
     * @Column(type="string", length=255, name="NAME")
     * 
     * @var string
     */
    private $name;

    /**
     * @Column(type="string", length=255, name="FIRST_NAME")
     * 
     * @var string
     */
    private $firstname;

    /**
     * @Column(type="string", length=255, name="JOB", nullable=true)
     * 
     * @var string
     */
    private $job;

    /**
     * Une Person rédige plusieurs Course.
     * @OneToMany(targetEntity="Entity\Course", mappedBy="author")
     */
    private $myCourses;

    /**
     * Plusieurs Persons suivent plusieurs cours.
     * @ManyToMany(targetEntity="Entity\Course", inversedBy="students")
     * @JoinTable(name="PERSON_COURSE",
     * joinColumns={@JoinColumn(name="PERSON_ID", referencedColumnName="PERSON_ID")},
     * inverseJoinColumns={@JoinColumn(name="COURSE_ID", referencedColumnName="COURSE_ID")}
     * )
     */
    private $myTrainingCourses;

    public function __construct()
    {
        $this->myCourses = new \Doctrine\Common\Collections\ArrayCollection();
        $this->myTrainingCourses = new \Doctrine\Common\Collections\ArrayCollection();
    }

    /**
     *
     * @return the $id
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     *
     * @return the $name
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     *
     * @return the $firstname
     */
    public function getFirstname()
    {
        return $this->firstname;
    }

    /**
     *
     * @return the $job
     */
    public function getJob()
    {
        return $this->job;
    }

    /**
     *
     * @param number $id            
     */
    public function setId($id)
    {
        $this->id = $id;
    }

    /**
     *
     * @param string $name            
     */
    public function setName($name)
    {
        $this->name = $name;
    }

    /**
     *
     * @param string $firstname            
     */
    public function setFirstname($firstname)
    {
        $this->firstname = $firstname;
    }

    /**
     *
     * @param string $job            
     */
    public function setJob($job)
    {
        $this->job = $job;
    }

    /**
     *
     * @param Course $course            
     */
    public function addMyCourse(Course $course): void
    {
        $this->myCourses->add($course);
    }

    /**
     *
     * @return \Doctrine\Common\Collections\ArrayCollection
     */
    public function getMyCourses(): \Doctrine\Common\Collections\ArrayCollection
    {
        return $this->myCourses;
    }

    public function addMyTrainingCourse(Course $myTrainingCourse): void
    {
        $this->myTrainingCourses->add($myTrainingCourse);
    }

    public function getMyTrainingCourses(): \Doctrine\Common\Collections\ArrayCollection
    {
        return $this->myTrainingCourses;
    }

    
    public function __toString(): string
    {
        return 'Person{id:' . $this->id . ',firstname:' . $this->firstname . ',name:' . $this->name . ',job:' . $this->job . '}';
    }
}

