<?php
namespace Service;

use Doctrine\ORM\EntityManager;
use Entity\Person;
use Entity\Course;

/**
 * La classe de service qui gère de haut niveau l'aspect métier ainsi que les transactions
 * Traitez les transactions au plus haut niveau possible pour mieux gérer les plantages, oui cela arrive
 * 
 * @author Christophe PEQUIGNAT
 *
 */
class CourseService extends AbstractService
{
    
    public function __construct(EntityManager $em){
        $this->setEntityManager($em);
    }
    
    
    /**
     * Initialise la base de données avec des valeurs ceci dans une transaction unique
     */
    public function initExample() : void{
        $this->getEntityManager()->transactional(function(EntityManager $em){
            $author = new Person();
            $author->setFirstname("Christophe");
            $author->setName("Péquignat");
            $author->setJob("Software Architect");
            
            $course = new Course();
            $course->setAuthor($author);
            $course->setTitle('Mise en oeuvre de Doctrine 2.6');
            
            $author->addMyCourse($course);
            
            $student = new Person();
            $student->setFirstname("John");
            $student->setName("Doe");
            $student->setJob("Freelance");
            
            
            $em->getRepository('Entity\Person')->addPerson($author);
            $em->getRepository('Entity\Course')->addCourse($course);
            $em->getRepository('Entity\Person')->addPerson($student);
            
            $course->addStudent($student);
            $student->addMyTrainingCourse($course);
            //En sortie de la méthode le relation ManyToMany est enregistrée en base
        });
    }
    
    
    /**
     * Efface la base de données de toutes ses valeurs ceci dans une transaction unique
     */
    public function dropExample() : void{
        $this->getEntityManager()->transactional(function(EntityManager $em){
            $em->getRepository('Entity\Course')->removeAll();
            $em->getRepository('Entity\Person')->removeAll();
        });
    }
    
    
    public function getAllPersons(){
        return $this->getEntityManager()->getRepository('Entity\Person')->getAllPersons();
    }
    
    public function getAllCourses(){
        return $this->getEntityManager()->getRepository('Entity\Course')->getAllCourses();
    }
}

